#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Plot influence of V_s30 predicted by CY14 model."""
import matplotlib.pyplot as plt

import pygmm

fig, ax = plt.subplots()

for v_s30 in [300, 600, 900]:
    s = pygmm.model.Scenario(
        mag=7, dist_jb=20, dist_x=20, dist_rup=25, dip=90, v_s30=v_s30
    )
    m = pygmm.ChiouYoungs2014(s)
    ax.plot(m.periods, m.spec_accels, label=str(v_s30))

ax.set_xlabel("Period (s)")
ax.set_xscale("log")

ax.set_ylabel("5%-Damped Spectral Accel. (g)")
ax.set_yscale("log")

ax.grid()

ax.legend(title="$V_{s30}$ (m/s)")

plt.show()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import find_packages
from setuptools import setup

with open("README.rst") as fp:
    readme = fp.read()

with open("HISTORY.rst") as fp:
    history = fp.read()

setup(
    name="pygmm",
    version="0.6.4",
    description="Ground motion models implemented in Python.",
    long_description=readme + "\n\n" + history,
    author="Albert Kottke",
    author_email="albert.kottke@gmail.com",
    url="https://github.com/arkottke/pygmm",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        "matplotlib",
        "numpy",
        "scipy >= 0.17.0",
        "six",
    ],
    license="MIT",
    zip_safe=False,
    keywords="pygmm",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python",
        "Topic :: Scientific/Engineering",
        "Intended Audience :: Science/Research",
    ],
    setup_requires=[
        "pytest-runner",
    ],
    tests_require=[
        "pytest >= 2.9.0",
        "pytest-cov",
        "pytest-flake8",
    ],
)
